pub struct ClockRef {
pub name: Option<String>,
pub phandle: Phandle,
pub cells: u32,
pub specifier: Vec<u32>,
}Expand description
Clock reference, used to parse clocks property.
According to the device tree specification, the clocks property format is:
clocks = <&clock_provider specifier [specifier ...]> [<&clock_provider2 ...>]
Each clock reference consists of a phandle and several specifier cells,
the number of specifiers is determined by the target clock provider’s #clock-cells property.
Fields
name: Option<String>Clock name, from clock-names property
phandle: PhandlePhandle of the clock provider
cells: u32#clock-cells value of the provider
specifier: Vec<u32>Clock selector (specifier), usually the first value is used to select clock output Length is determined by provider’s #clock-cells
Implementations